function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

import objectPath from 'object-path';
import mapValues from 'lodash.mapvalues';

import applyGenericTheme from './applyGenericTheme';

var ThemeManager = function () {
  function ThemeManager() {
    _classCallCheck(this, ThemeManager);

    this.themes = {};
    this.breakpoints = [];
  }

  ThemeManager.prototype.getBreakpoints = function getBreakpoints() {
    if (this.breakpoints.length === 0) {
      throw new Error('You have to provide an array of breakpoints');
    }

    return this.breakpoints;
  };

  ThemeManager.prototype.setBreakpoints = function setBreakpoints(breakpoints) {
    this.breakpoints = breakpoints;
  };

  ThemeManager.prototype.createTheme = function createTheme(namespace, theme) {
    this.themes[namespace] = theme;

    if (!theme['default']) {
      throw new Error('To create a theme it must have a "default" key');
    }

    return applyGenericTheme(namespace);
  };

  ThemeManager.prototype.getDefaultThemes = function getDefaultThemes() {
    return mapValues(this.themes, function (theme) {
      return theme.default;
    });
  };

  ThemeManager.prototype.getTheme = function getTheme(themePath) {
    var theme = objectPath.get(this.themes, themePath);

    if (!theme) {
      throw new Error('No theme for the given path: \'' + themePath + '\'');
    }

    return theme;
  };

  return ThemeManager;
}();

// This is a singleton


export default new ThemeManager();