'use strict';

exports.__esModule = true;

var _objectPath = require('object-path');

var _objectPath2 = _interopRequireDefault(_objectPath);

var _lodash = require('lodash.mapvalues');

var _lodash2 = _interopRequireDefault(_lodash);

var _applyGenericTheme = require('./applyGenericTheme');

var _applyGenericTheme2 = _interopRequireDefault(_applyGenericTheme);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var ThemeManager = function () {
  function ThemeManager() {
    _classCallCheck(this, ThemeManager);

    this.themes = {};
    this.breakpoints = [];
  }

  ThemeManager.prototype.getBreakpoints = function getBreakpoints() {
    if (this.breakpoints.length === 0) {
      throw new Error('You have to provide an array of breakpoints');
    }

    return this.breakpoints;
  };

  ThemeManager.prototype.setBreakpoints = function setBreakpoints(breakpoints) {
    this.breakpoints = breakpoints;
  };

  ThemeManager.prototype.createTheme = function createTheme(namespace, theme) {
    this.themes[namespace] = theme;

    if (!theme['default']) {
      throw new Error('To create a theme it must have a "default" key');
    }

    return (0, _applyGenericTheme2.default)(namespace);
  };

  ThemeManager.prototype.getDefaultThemes = function getDefaultThemes() {
    return (0, _lodash2.default)(this.themes, function (theme) {
      return theme.default;
    });
  };

  ThemeManager.prototype.getTheme = function getTheme(themePath) {
    var theme = _objectPath2.default.get(this.themes, themePath);

    if (!theme) {
      throw new Error('No theme for the given path: \'' + themePath + '\'');
    }

    return theme;
  };

  return ThemeManager;
}();

// This is a singleton


exports.default = new ThemeManager();
module.exports = exports['default'];